package hudson.plugins.artifactsize;

import hudson.Extension;
import hudson.model.Job;
import hudson.model.Run;
import hudson.views.ListViewColumn;
import hudson.views.ListViewColumnDescriptor;

import org.apache.commons.io.FileUtils;
import org.kohsuke.stapler.DataBoundConstructor;

/**
 * This {@link ListViewColumn} adds a (optional) new column to user defined
 * views that shows the total size of all archived artifacts of the last build
 * of a job.
 * 
 * @author swiest
 */
public class ArtifactSizeColumn extends ListViewColumn {

  private final boolean roundedFormat;

  @DataBoundConstructor
  public ArtifactSizeColumn(boolean roundedFormat) {
    this.roundedFormat = roundedFormat;
  }
  
  public ArtifactSizeColumn() {
    this(false);
  }
  
  public boolean isRoundedFormat() {
    return roundedFormat;
  }

  public String getArtifactSize(Job job) {
    Run lastRun = job.getLastBuild();
    if (lastRun == null) {
      return "No build found";
    }

    ArtifactSizeAction asa = lastRun
        .getAction(ArtifactSizeAction.class);
    if (asa == null) {
      return "Not recorded";
    }

    long totalSize = asa.getTotalSize();
    if (roundedFormat) {
      return FileUtils.byteCountToDisplaySize(totalSize);
    } else {
      return totalSize + " byte(s)";
    }
  }

  @Extension
  public static class ArtifactSizeColumnDescriptor extends
      ListViewColumnDescriptor {

    @Override
    public String getDisplayName() {
      return "Artifact Size";
    }

  }
}