package hudson.plugins.artifactsize;

import hudson.Extension;
import hudson.cli.CLICommand;
import hudson.model.AbstractProject;
import hudson.model.Hudson;
import hudson.model.Run;

import java.io.PrintStream;
import java.util.ArrayList;
import java.util.List;

import org.kohsuke.args4j.Argument;

/**
 * This CLI command allows querying the total size of artifacts from a Hudson
 * server remotely via the command line.
 * 
 * @author swiest
 */
@Extension
public class ArtifactSizeCommand extends CLICommand {

  @Override
  public String getShortDescription() {
    return "Lists artifact size of the last build.";
  }

  @Override
  protected void printUsageSummary(PrintStream stderr) {
    stderr.print("Lists artifact size of the last build ");
    stderr.println("of a given job.");
    stderr.println("If no job is given, all jobs are listed.");
    stderr.println("Valid parameters are:");
  }

  @Argument(metaVar = "JOB", usage = "Job name")
  public AbstractProject<?, ?> job;

  @Override
  protected int run() throws Exception {
    List<AbstractProject> jobsToList = new ArrayList<AbstractProject>();
    if (job != null) {
      jobsToList.add(job);
    } else {
      jobsToList.addAll(Hudson.getInstance().getAllItems(AbstractProject.class));
    }

    for (AbstractProject job : jobsToList) {
      stdout.printf("%-20s", job.getName());
      Run lastRun = job.getLastBuild();
      if (lastRun == null) {
        stdout.println("No build found");
      } else {
        ArtifactSizeAction asa = lastRun.getAction(ArtifactSizeAction.class);
        if (asa == null) {
          stdout.println("Built prior to installation of ArtifactSize");
        } else {
          long totalSize = asa.getTotalSize();
          stdout.printf("%14d byte(s)", totalSize);
          stdout.printf("%3d artifacts(s)\n", lastRun.getArtifacts().size());
        }
      }
    }

    return 0;
  }

}